@@ -1,6 +1,6 @@
 package App::JobLog::Log::Synopsis;
 BEGIN {
-  $App::JobLog::Log::Synopsis::VERSION = '1.000';
+  $App::JobLog::Log::Synopsis::VERSION = '1.001';
 }
 
 # ABSTRACT: consolidates App::JobClock::Log::Event objects for display
@@ -188,7 +188,7 @@ sub last_event { ( $_[0]->events )[-1] }
 sub _new {
     my ( $event, $merge_level ) = @_;
     carp 'requires event argument'
-      unless $event && ref $event eq 'App::JobLog::Log::Event';
+      unless $event && $event->isa('App::JobLog::Log::Event');
     my ( $one_interval, $one_day );
     given ($merge_level) {
         when (MERGE_ALL)      { ( $one_interval, $one_day ) = ( 0, 0 ) }
@@ -268,7 +268,7 @@ App::JobLog::Log::Synopsis - consolidates App::JobClock::Log::Event objects for
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 DESCRIPTION
 
